<?php

/**
 * Created by PhpStorm.
 * User: Alessandro
 * Date: 27/11/15
 * Time: 17:06
 */
class TmbCvettaCatalogue
{
	protected static $instance;
	protected $debug = false;
	public $params;
	public $errors;
	public $debug_base_url = null;

	public function __construct($id_shop = null, $id_lang = null)
	{
		$this->context = Context::getContext();

		if (!is_null($id_shop))
			$this->context->shop = new Shop($id_shop);


		if (!is_null($id_lang) && (int)$id_lang > 0)
			$this->context->language = new Language($id_lang);
		else
			$this->context->language = new Language(Configuration::get('PS_LANG_DEFAULT'));

		$this->id_default_group = 3;

		$params = TmbFeedParameters::getParam();
		$this->params = $params['params'];
	}

	public function create()
	{
		$res = true;
		$shop = $this->context->shop;

		$protocol = Tools::getShopProtocol();
		$base = (($protocol == 'http://') ? $protocol.$shop->domain_ssl : $protocol.$shop->domain);
		$base_url = $base.$shop->getBaseURI();

		if (!is_null($this->debug_base_url))
			$base_url = $this->debug_base_url;

		// Aggiornamento catalogo
		$create_sql = file_get_contents(__DIR__.'/../sql/catalogue.sql');
		$create_sql = str_replace('{BASEURL}', $base_url, $create_sql);
		$create_sql = str_replace('{ID_SHOP}', $shop->id, $create_sql);
		$create_sql = str_replace('{DB_PREFIX}', _DB_PREFIX_, $create_sql);

		$res = (bool)Db::getInstance()->execute($create_sql);

		// Creo la tabella per i feed
		$create_feed_sql = file_get_contents(__DIR__.'/../sql/feed.sql');
		$create_feed_sql = str_replace('{ID_SHOP}', $shop->id, $create_feed_sql);
		$create_feed_sql = str_replace('{DB_PREFIX}', _DB_PREFIX_, $create_feed_sql);

		$res &= Db::getInstance()->execute($create_feed_sql);

		// Elimina tutti i feed per lo shop selezionato
		$selected_cvetta_lang = Configuration::get('TMBCVETTA_FEED_LANG');
		if (empty($selected_cvetta_lang))
			$selected_cvetta_lang = array($this->context->language->id);
		else
			$selected_cvetta_lang = explode(',', $selected_cvetta_lang);
		foreach ($selected_cvetta_lang as $id_lang)
		{
			$feed = new TmbCvettaFeed($this->context->shop->id, $id_lang);
			$feed->deleteFeed();
		}
		return $res;
	}

	public function getRetailPrice($id_product)
	{
		$usereduc = false;
		return $this->getPrice($id_product, $usereduc);
	}

	public function getFinalPrice($id_product)
	{
		$usereduc = true;
		return $this->getPrice($id_product, $usereduc);
	}

	public function getPrice($id_product, $usereduc)
	{
		$id_shop = (int)$this->context->shop->id;
		$id_product_attribute = 0;
		$id_country = (int)$this->context->country->id;
		$id_state = 0;
		$zipcode = 0;
		$id_currency = Validate::isLoadedObject($this->context->currency) ? (int)$this->context->currency->id : (int)Configuration::get('PS_CURRENCY_DEFAULT');
		$id_group = 3;
		$quantity = 1;
		$use_tax = true;
		$decimals = 6;
		$only_reduc = false;
		$with_ecotax = true;
		$specific_price = null;
		$use_group_reduction = false;

		$price = Product::priceCalculation($id_shop, $id_product, $id_product_attribute, $id_country, $id_state, $zipcode, $id_currency, $id_group, $quantity, $use_tax, $decimals, $only_reduc, $usereduc, $with_ecotax, $specific_price, $use_group_reduction);

		return $price;
	}

	public static function getImagesById($id_product)
	{
		$name = Db::getInstance()->getValue('SELECT name FROM '._DB_PREFIX_.'product_lang WHERE id_product = '.$id_product.' AND id_lang = '.(int)Context::getContext()->language->id);
		$list = Db::getInstance()->executeS('
			SELECT image_shop.`cover`, i.`id_image`, il.`legend`, i.`position`
			FROM `'._DB_PREFIX_.'image` i
			'.Shop::addSqlAssociation('image', 'i').'
			LEFT JOIN `'._DB_PREFIX_.'image_lang` il ON (i.`id_image` = il.`id_image` AND il.`id_lang` = '.(int)Context::getContext()->language->id.')
			WHERE i.`id_product` = '.(int)$id_product.'
			ORDER BY `position`'
		);
		$link = new Link();

		foreach ($list as $item)
		{
			$url = $link->getImageLink($name, $item['id_image']);
			$images[] = array('src' => $url);
		}

		return $images;
	}

	public function getIndexes()
	{

		$total_items = 0;
		$prices_indexed = 0;

		$res = true;

		$sql_items = "SELECT TABLE_NAME
			FROM information_schema.tables
			WHERE TABLE_SCHEMA = '"._DB_NAME_."' 
			AND TABLE_NAME = '"._DB_PREFIX_."tmbcvetta_items".$this->context->shop->id."';";
		$res &= (bool)Db::getInstance()->getValue($sql_items);

		if ($res)
		{
			$total_items = $this->getTotalItems();
		}

		$feed_indexed = $this->getFeedIndexed();

		return array('total_items' => $total_items, 'feed_indexed' => $feed_indexed);
	}

	public function getTotalItems()
	{
		$str_restrictions = $this->getRestrictionProducts();
		$str_categories = $this->getSelectedCategories();
		$sql = "SELECT COUNT(id_product) FROM "._DB_PREFIX_."tmbcvetta_items".$this->context->shop->id." WHERE 1"
			.$str_restrictions
			.$str_categories;
		
		return (int)Db::getInstance()->getValue(
			$sql
		);
	}

	public function getFeedIndexed()
	{
		$feed_indexed = array();

		$selected_cvetta_lang = Configuration::get('TMBCVETTA_FEED_LANG');
		if (strpos($selected_cvetta_lang, ',') !== false)
			$selected_cvetta_lang = explode(',', $selected_cvetta_lang);
		else
			$selected_cvetta_lang = array($selected_cvetta_lang);

		if (!empty($selected_cvetta_lang))
		{
			$sql = "SELECT TABLE_NAME
					FROM information_schema.tables
					WHERE TABLE_SCHEMA = '"._DB_NAME_."' 
					AND TABLE_NAME = '"._DB_PREFIX_."tmbcvetta_feed".$this->context->shop->id."';";

			if (!(bool)Db::getInstance()->getValue($sql))
			{
				foreach ($selected_cvetta_lang as $cvetta_lang)
					$feed_indexed[(int)$cvetta_lang] = 0;
			}
			else
			{
				foreach ($selected_cvetta_lang as $cvetta_lang)
				{
					$sql = "SELECT count(id_product) FROM "._DB_PREFIX_."tmbcvetta_feed".(int)$this->context->shop->id
					    ." WHERE id_lang = ".(int)$cvetta_lang;
					$feed_indexed[(int)$cvetta_lang] = (int)Db::getInstance()->getValue($sql);
				}
			}
		}

		return $feed_indexed;
	}
	
	public function getRestrictionProducts($alias = '')
	{
		$str_restrinction = '';
		
		if (isset($this->params['restrict_products']) && !empty($this->params['restrict_products']))
		{
			$rules = json_decode($this->params['restrict_products'], true);
			foreach ($rules as $rule)
			{
				if ((int)$rule == 1)
					$str_restrinction .= " AND ".($alias != '' ? $alias.'.' : '')."active = 1";
				
				if ((int)$rule == 2)
					$str_restrinction .= " AND ".($alias != '' ? $alias.'.' : '')."quantity > 0";
				
				if ((int)$rule == 3)
					$str_restrinction .= " AND ".($alias != '' ? $alias.'.' : '')."image_link IS NOT NULL";
			}
		}

		return $str_restrinction;
	}

	public function getSelectedCategories()
	{
		if (isset($this->params['id_category']) AND ! empty($this->params['id_category']))
		{
			$categories = json_decode($this->params['id_category'], true);
			$str_categories = implode('|', $categories);
			return " AND categories REGEXP '(^|;)(".$str_categories.")(;|$)'";
		}

		return '';
	}

	public function getErrors()
	{
		return $this->errors;
	}

	public function setDebug($debug)
	{
		$this->debug = $debug;
	}

}