<?php
require_once __DIR__ . '/../../../config/config.inc.php';
require_once __DIR__ . '/../classes/TmbCvettaCatalogue.php';
require_once __DIR__ . '/../classes/TmbCvettaFeed.php';
require_once __DIR__ . '/../classes/TmbFeedParameters.php';

file_put_contents('log_accessi.log', date("Y-m-d H:i:s")."\n ".json_encode($_SERVER)."\n**********************\n\n\n",FILE_APPEND);

$id_shop = (int)Tools::getValue('id_shop', 0);
if ($id_shop == 0)
    $id_shop = (int)Context::getContext()->shop->id;
validateShop($id_shop);

$id_lang = Tools::getValue('id_lang', 0);
if ($id_lang == 0)
    $id_lang = (int)Configuration::get('PS_LANG_DEFAULT');
validateLang($id_lang);

$base_url = getScriptBaseUrl($id_shop);
//pt($_SERVER);
//die(filter_input(INPUT_SERVER, 'HTTP_USER_AGENT'));

$debug = (bool)Tools::getValue('debug', 0);
$limit = Tools::getValue('limit', Configuration::get('TMBCVETTA_FEED_LIMIT'));
$task = Tools::getValue('task', null);

$ajax = false;
$httprequest = $_SERVER['HTTP_X_REQUESTED_WITH'];
if (!empty($httprequest) && strtolower($httprequest) == 'xmlhttprequest')
    $ajax = true;

// Create catalogue
if ($task == 'create')
{
    $catalogue = new TmbCvettaCatalogue($id_shop);
    if (!is_null(Configuration::get('TMBCVETTA_DEBUG_BASEURL'))
        && trim(Configuration::get('TMBCVETTA_DEBUG_BASEURL')) != ""
    )
        $catalogue->debug_base_url = Configuration::get('TMBCVETTA_DEBUG_BASEURL');

    if ($catalogue->create())
    {
        $indexes = $catalogue->getIndexes();

        if ($ajax)
        {
            $response = array_merge(array('success' => 1, 'errors' => null), $indexes);
            die(json_encode($response));
        }
        else
        {
            die("Catalogue create\n");
        }
    }
}
// Generate feed
elseif ($task == 'feed')
{
    $feed = new TmbCvettaFeed($id_shop, $id_lang);
    $feed->setDebug($debug);
    $feed->setLimit($limit);
    if ((bool)$feed->generateFeed())
    {
        $indexes = $feed->getIndexes();
        $feed_indexed = (int)$indexes['feed_indexed'][$id_lang];
        $total_items = (int)$indexes['total_items'];
        $current_indexes = 'Feed items ' . $feed_indexed . ' / ' . $total_items;

        if ($feed_indexed < $total_items)
        {
            if (!$ajax)
            {
               // echo $current_indexes;
                header('location: ' . $base_url . 'catalogue.php?task=feed&id_shop=' . $id_shop . '&id_lang=' . $id_lang."&start=false");
            }
        }
        elseif ($feed_indexed == $total_items)
        {
            if (!empty(Configuration::get('TMBCVETTA_USERNAME')) && !empty(Configuration::get('TMBCVETTA_PASSWORD')))
            {
            }
        }

        if ($ajax)
        {

            if (!$debug)
                $response = array_merge(array('continue' => 1, 'errors' => null), $indexes);
            else
                die;

            die(json_encode($response));
        }
        else
        {
            if($feed_indexed == $total_items) {
                $feed->closeFile();
                $feed->sendFeed();
            }
            die($current_indexes . "\n");
        }
    }
    else
    {
        if ($ajax)
        {
            // Upload feed
            $feed->sendFeed();
            $indexes = $feed->getIndexes();
            die(json_encode(array_merge(array('continue' => 0, 'errors' => array('No feed to generate')),$indexes)));
        }
        else
        {
            // Upload feed
            $feed->sendFeed();
            die("Feed Generated\n");
        }
    }
}
// Delete feed
elseif ($task == 'delete_feed')
{
    $feed = new TmbCvettaFeed($id_shop, $id_lang);
    $res = $feed->deleteFeed();
    $indexes = $feed->getIndexes();
    $feed_indexed = (int)$indexes['feed_indexed'][$id_lang];
    $total_items = (int)$indexes['total_items'];
    $current_indexes = 'Feed items ' . $feed_indexed . ' / ' . $total_items;

    if ($ajax)
    {
        if (!$debug)
            $response = array_merge(array('success' => 1, 'errors' => null), $indexes);

        die(json_encode($response));
    }
    else
    {
        die($current_indexes . "\n");
    }
}

die('No action selected');

function validateShop($id_shop)
{
    $shop_exists = false;
    $shops = Shop::getShops();
    foreach ($shops as $shop)
    {
        if ((int)$shop['id_shop'] == $id_shop)
        {
            $shop_exists = true;
            break;
        }
    }
    if (!$shop_exists)
        die('Il negozio selezionato non esiste');
}

function validateLang($id_lang)
{
    $language = Language::getLanguage($id_lang);
    if (!$language || empty($language))
        die('La lingua selezionata non esiste');
}

function getScriptBaseUrl($id_shop)
{
    $shop = new Shop($id_shop);
    $protocol = Tools::getShopProtocol();
    $domain = (($protocol == 'http://') ? $protocol . $shop->domain_ssl : $protocol . $shop->domain);
    return $domain . $shop->physical_uri . 'modules/ittwebcvetta/feed/';
}

function isCli()
{
    if (!filter_input(INPUT_SERVER, 'HTTP_USER_AGENT'))
        return false;
    return true;
}
